
/* Generated data (by glib-mkenums) */

/**
 * SECTION: ibusenumtypes
 * @short_description: Enumeration definition in IBus.
 * @stability: Stable
 *
 * IBusEnumTypes lists IBus enumeration types.
 */
#ifndef __IBUS_ENUM_TYPES_H__
#define __IBUS_ENUM_TYPES_H__

#include <glib-object.h>

G_BEGIN_DECLS

/* enumerations from "ibusobject.h" */
/**
 * ibus_object_flags_get_type:
 * @returns: GType of IBUS_OBJECT_FLAGS
 *
 * Returns the type of IBUS_OBJECT_FLAGS as GType.
 */
GType ibus_object_flags_get_type (void) G_GNUC_CONST;

/**
 * IBUS_TYPE_OBJECT_FLAGS:
 * @returns: GType of IBUS_OBJECT_FLAGS
 *
 * Returns the type of IBUS_OBJECT_FLAGS as GType.
 */
#define IBUS_TYPE_OBJECT_FLAGS (ibus_object_flags_get_type ())

/* enumerations from "ibusattribute.h" */
/**
 * ibus_attr_type_get_type:
 * @returns: GType of IBUS_ATTR_TYPE
 *
 * Returns the type of IBUS_ATTR_TYPE as GType.
 */
GType ibus_attr_type_get_type (void) G_GNUC_CONST;

/**
 * IBUS_TYPE_ATTR_TYPE:
 * @returns: GType of IBUS_ATTR_TYPE
 *
 * Returns the type of IBUS_ATTR_TYPE as GType.
 */
#define IBUS_TYPE_ATTR_TYPE (ibus_attr_type_get_type ())
/**
 * ibus_attr_underline_get_type:
 * @returns: GType of IBUS_ATTR_UNDERLINE
 *
 * Returns the type of IBUS_ATTR_UNDERLINE as GType.
 */
GType ibus_attr_underline_get_type (void) G_GNUC_CONST;

/**
 * IBUS_TYPE_ATTR_UNDERLINE:
 * @returns: GType of IBUS_ATTR_UNDERLINE
 *
 * Returns the type of IBUS_ATTR_UNDERLINE as GType.
 */
#define IBUS_TYPE_ATTR_UNDERLINE (ibus_attr_underline_get_type ())

/* enumerations from "ibusproperty.h" */
/**
 * ibus_prop_type_get_type:
 * @returns: GType of IBUS_PROP_TYPE
 *
 * Returns the type of IBUS_PROP_TYPE as GType.
 */
GType ibus_prop_type_get_type (void) G_GNUC_CONST;

/**
 * IBUS_TYPE_PROP_TYPE:
 * @returns: GType of IBUS_PROP_TYPE
 *
 * Returns the type of IBUS_PROP_TYPE as GType.
 */
#define IBUS_TYPE_PROP_TYPE (ibus_prop_type_get_type ())
/**
 * ibus_prop_state_get_type:
 * @returns: GType of IBUS_PROP_STATE
 *
 * Returns the type of IBUS_PROP_STATE as GType.
 */
GType ibus_prop_state_get_type (void) G_GNUC_CONST;

/**
 * IBUS_TYPE_PROP_STATE:
 * @returns: GType of IBUS_PROP_STATE
 *
 * Returns the type of IBUS_PROP_STATE as GType.
 */
#define IBUS_TYPE_PROP_STATE (ibus_prop_state_get_type ())

/* enumerations from "ibustypes.h" */
/**
 * ibus_modifier_type_get_type:
 * @returns: GType of IBUS_MODIFIER_TYPE
 *
 * Returns the type of IBUS_MODIFIER_TYPE as GType.
 */
GType ibus_modifier_type_get_type (void) G_GNUC_CONST;

/**
 * IBUS_TYPE_MODIFIER_TYPE:
 * @returns: GType of IBUS_MODIFIER_TYPE
 *
 * Returns the type of IBUS_MODIFIER_TYPE as GType.
 */
#define IBUS_TYPE_MODIFIER_TYPE (ibus_modifier_type_get_type ())
/**
 * ibus_capabilite_get_type:
 * @returns: GType of IBUS_CAPABILITE
 *
 * Returns the type of IBUS_CAPABILITE as GType.
 */
GType ibus_capabilite_get_type (void) G_GNUC_CONST;

/**
 * IBUS_TYPE_CAPABILITE:
 * @returns: GType of IBUS_CAPABILITE
 *
 * Returns the type of IBUS_CAPABILITE as GType.
 */
#define IBUS_TYPE_CAPABILITE (ibus_capabilite_get_type ())
/**
 * ibus_preedit_focus_mode_get_type:
 * @returns: GType of IBUS_PREEDIT_FOCUS_MODE
 *
 * Returns the type of IBUS_PREEDIT_FOCUS_MODE as GType.
 */
GType ibus_preedit_focus_mode_get_type (void) G_GNUC_CONST;

/**
 * IBUS_TYPE_PREEDIT_FOCUS_MODE:
 * @returns: GType of IBUS_PREEDIT_FOCUS_MODE
 *
 * Returns the type of IBUS_PREEDIT_FOCUS_MODE as GType.
 */
#define IBUS_TYPE_PREEDIT_FOCUS_MODE (ibus_preedit_focus_mode_get_type ())
/**
 * ibus_orientation_get_type:
 * @returns: GType of IBUS_ORIENTATION
 *
 * Returns the type of IBUS_ORIENTATION as GType.
 */
GType ibus_orientation_get_type (void) G_GNUC_CONST;

/**
 * IBUS_TYPE_ORIENTATION:
 * @returns: GType of IBUS_ORIENTATION
 *
 * Returns the type of IBUS_ORIENTATION as GType.
 */
#define IBUS_TYPE_ORIENTATION (ibus_orientation_get_type ())
G_END_DECLS

#endif /* __IBUS_ENUM_TYPES_H__ */

/* Generated data ends here */

